aboutsummaryrefslogtreecommitdiffstats
path: root/Scripts
diff options
context:
space:
mode:
Diffstat (limited to 'Scripts')
-rwxr-xr-xScripts/build.sh3
1 files changed, 2 insertions, 1 deletions
diff --git a/Scripts/build.sh b/Scripts/build.sh
index 2e48dacc..82c788de 100755
--- a/Scripts/build.sh
+++ b/Scripts/build.sh
@@ -24,8 +24,9 @@ echo 'Updating build version...'
# Add the build/bundle version
"${SRCROOT}/Scripts/build-version.pl"
# Remove the .ibplugin from within BWToolkit
rm -rf "${BUILD_PRODUCT}/Contents/Frameworks/BWToolkitFramework.framework/Versions/A/Resources/BWToolkit.ibplugin"
+rm -rf "${BUILD_PRODUCT}/Contents/Frameworks/ShortcutRecorder.framework/Versions/A/Resources/ShortcutRecorder.ibplugin"
# Perform localisation updates for 'Release' or 'Distribution' builds
if [[ "$CONFIGURATION" == 'Release' || "$CONFIGURATION" == 'Distribution' ]]
@@ -24,8 +24,9 @@ echo 'Updating build version...'
# Add the build/bundle version
"${SRCROOT}/Scripts/build-version.pl"
-# Remove the .ibplugin from within BWToolkit
+# Remove the .ibplugin from within frameworks
rm -rf "${BUILD_PRODUCT}/Contents/Frameworks/BWToolkitFramework.framework/Versions/A/Resources/BWToolkit.ibplugin"